/*
 * @Author: PoJun
 * @Date: 2023-05-14 17:52:10
 * @LastEditors: PoJun
 * @LastEditTime: 2024-01-04 15:25:49
 * @Message: Nothing
 */
import Vue from "vue";
import Vuex from "vuex";

Vue.use(Vuex);

let lifeData = {};

try {
    // 尝试获取本地是否存在lifeData变量，第一次启动APP时是不存在的
    lifeData = uni.getStorageSync("lifeData");
} catch (e) {
    console.log(e);
}

// 需要永久存储，且下次APP启动需要取出的，在state中的变量名
let saveStateKeys = ["vuex_userInfo", "vuex_historyKeys"];
// 保存变量到本地存储中
const saveLifeData = function (key, value) {
    // 判断变量名是否在需要存储的数组中
    if (saveStateKeys.indexOf(key) != -1) {
        // 获取本地存储的lifeData对象，将变量添加到对象中
        let tmp = uni.getStorageSync("lifeData");
        // 第一次打开APP，不存在lifeData变量，故放一个{}空对象
        tmp = tmp ? tmp : {};
        tmp[key] = value;
        // 执行这一步后，所有需要存储的变量，都挂载在本地的lifeData对象中
        uni.setStorageSync("lifeData", tmp);
    }
};
const store = new Vuex.Store({
    state: {
        vuex_token: "",
        vuex_dict: {}, //字典数据
        // 人员信息展开, 在使用的时候方便使用, 使用null是为了在未登录情况小程序端不出现undefined
        vuex_userInfo: lifeData.vuex_userInfo ? lifeData.vuex_userInfo : null, //登录信息
        vuex_affairNum: 0,
    },
    mutations: {
        $uStore(state, payload) {
            // 判断是否多层级调用，state中为对象存在的情况，诸如user.info.score = 1
            let nameArr = payload.name.split(".");
            let saveKey = "";
            let len = nameArr.length;
            if (nameArr.length >= 2) {
                let obj = state[nameArr[0]];
                for (let i = 1; i < len - 1; i++) {
                    obj = obj[nameArr[i]];
                }
                obj[nameArr[len - 1]] = payload.value;
                saveKey = nameArr[0];
            } else {
                // 单层级变量，在state就是一个普通变量的情况
                state[payload.name] = payload.value;
                saveKey = payload.name;
            }
            // 保存变量到本地，见顶部函数定义
            saveLifeData(saveKey, state[saveKey]);
        },
        $updateLoginInfo(state, res) {
            // 数据更新,把需要且有用的人员相关信息直接放在第一层级,只能做展示用
            const info = {
                ...res.attr.OrgPerson,
                name: res.attr.systemUser?.name,
                otherName: res.attr.systemUser?.otherName,
                imageLogo: res.attr.systemUser?.imageLogo,
                ...res,
            };
            state.vuex_userInfo = info;
            saveLifeData("vuex_userInfo", info);
        },
        $updateAffairInfo(state, num = 0) {
            state.vuex_affairNum = num;
        },
    },
    actions: {
        // 获取登录信息, 在多个地方需要重新获取
        async UPDATELOGININFO({ commit }) {
            const data = await uni.$uv.http.get("/web/login_info", { custom: { toast: false } });
            if (data) {
                commit("$updateLoginInfo", data);
            }
        },
        // 待办数量接口
        async UPDATEAFFAIRINFO({ commit }) {
            const num = await uni.$uv.http.get("/affairs/waitdo_count", { custom: { toast: false } });
            try {
                commit("$updateAffairInfo", num ? num : 0);
            } catch (error) {
                console.log(error);
            }
        },
    },
});

export default store;
